/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.camel.component.sqlplus;

import metridoc.camel.component.sqlplus.dao.SqlPlusDao;
import metridoc.camel.component.sqlplus.impl.dao.SpringSqlPlusDao;
import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.impl.DefaultConsumer;

/**
 * @author Narine Ghochikyan
 */
public class SqlStreamConsumer extends DefaultConsumer {

    SqlPlusEndpoint endpoint;
    private SqlPlusDao sqlPlusDao;

    public SqlStreamConsumer(SqlPlusEndpoint endpoint, Processor processor) {
        super(endpoint, processor);
        this.endpoint = endpoint;
        this.sqlPlusDao = new SpringSqlPlusDao(endpoint.getDataSource());
    }

    @Override
    protected void doStart() throws Exception {
        super.doStart();
        Exchange exchange = endpoint.createExchange();
        String query = endpoint.getQuery().trim();
        if (!query.startsWith("select")) {
            query = "select * from " + query;
        }
        exchange.getIn().setBody(sqlPlusDao.queryForRowSet(query, endpoint.getFetchSize()));
        getProcessor().process(exchange);
    }
}
